@@ -1,10 +1,14 @@
-/* $Id: failure.h,v 1.2 2000/08/26 18:27:17 marekm Exp $ */
+/* $Id: failure.h,v 1.4 2005/06/10 18:35:17 kloczek Exp $ */
 #ifndef _FAILURE_H_
 #define _FAILURE_H_
 
 #include "defines.h"
 #include "faillog.h"
+#ifdef HAVE_UTMPX_H
+#include <utmpx.h>
+#else
 #include <utmp.h>
+#endif
 
 /*
  * failure - make failure entry
@@ -12,7 +16,7 @@
  *	failure() creates a new (struct faillog) entry or updates an
  *	existing one with the current failed login information.
  */
-extern void failure(uid_t, const char *, struct faillog *);
+extern void failure (uid_t, const char *, struct faillog *);
 
 /*
  * failcheck - check for failures > allowable
@@ -22,7 +26,7 @@ extern void failure(uid_t, const char *, struct faillog *);
  *	returns FALSE to indicate that the login should be denied even though
  *	the password is valid.
  */
-extern int failcheck(uid_t, struct faillog *, int);
+extern int failcheck (uid_t, struct faillog *, int);
 
 /*
  * failprint - print line of failure information
@@ -30,7 +34,7 @@ extern int failcheck(uid_t, struct faillog *, int);
  *	failprint takes a (struct faillog) entry and formats it into a
  *	message which is displayed at login time.
  */
-extern void failprint(const struct faillog *);
+extern void failprint (const struct faillog *);
 
 /*
  * failtmp - update the cummulative failure log
@@ -38,7 +42,10 @@ extern void failprint(const struct faillog *);
  *	failtmp updates the (struct utmp) formatted failure log which
  *	maintains a record of all login failures.
  */
-extern void failtmp(const struct utmp *);
-
+#ifdef HAVE_UTMPX_H
+extern void failtmp (const struct utmpx *);
+#else
+extern void failtmp (const struct utmp *);
 #endif
 
+#endif
