@@ -9,16 +9,15 @@
 
 #include <config.h>
 
-#include "rcsid.h"
-RCSID ("$Id: xmalloc.c,v 1.5 2004/05/06 21:31:33 kloczek Exp $")
+#ident "$Id: xmalloc.c,v 1.8 2006/01/23 09:46:30 kloczek Exp $"
+
 #include <stdio.h>
 #include "defines.h"
-
 char *xmalloc (size_t size)
 {
 	char *ptr;
 
-	ptr = malloc (size);
+	ptr = (char *) malloc (size);
 	if (!ptr && size) {
 		fprintf (stderr, _("malloc(%d) failed\n"), (int) size);
 		exit (13);
